@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@ our @EXPORT = qw(
 
     needrestart_ui
     needrestart_ui_list
+    needrestart_interp_configure
     needrestart_interp_check
     needrestart_interp_source
     needrestart_cont_check
@@ -80,7 +81,7 @@ our %EXPORT_TAGS = (
     )],
 );
 
-our $VERSION = '3.4';
+our $VERSION = '3.7';
 my $LOGPREF = '[Core]';
 
 my %UIs;
@@ -135,13 +136,20 @@ sub needrestart_ui_list {
 
 
 my %Interps;
+my $InterpConf;
 my %InterpCache;
 my $idebug;
 
-sub needrestart_interp_register($) {
-    my $pkg = shift;
+sub needrestart_interp_configure($) {
+    my $conf = shift;
+    $InterpConf = $conf;
+}
 
-    $Interps{$pkg} = new $pkg($idebug);
+sub needrestart_interp_register($$) {
+    my $pkg = shift;
+    my $confkey = shift;
+
+    $Interps{$pkg} = new $pkg($idebug, $InterpConf->{$confkey});
 }
 
 sub needrestart_interp_init($) {
@@ -155,11 +163,12 @@ sub needrestart_interp_init($) {
     }
 }
 
-sub needrestart_interp_check($$$$) {
+sub needrestart_interp_check($$$$$) {
     my $debug = shift;
     my $pid = shift;
     my $bin = shift;
     my $blacklist = shift;
+    my $tolerance = shift;
 
     needrestart_interp_init($debug) unless(%Interps);
 
@@ -176,7 +185,7 @@ sub needrestart_interp_check($$$$) {
 		delete($files{$path});
 	    }
 
-	    if(grep {!defined($_) || $_ > $ps->start} values %files) {
+	    if(grep {!defined($_) || $_ > $ps->start + $tolerance} values %files) {
 		if($debug) {
 		    print STDERR "$LOGPREF #$pid uses obsolete script file(s):";
 		    print STDERR join("\n$LOGPREF #$pid  ", '', map {(!defined($files{$_}) || $files{$_} > $ps->start ? $_ : ())} keys %files);
@@ -258,7 +267,7 @@ sub needrestart_cont_get($) {
 	$n =~ s/^NeedRestart::CONT:://;
 
 	my %c = $cont->get;
-	
+
 	map {
 	    ("$n $_" => $c{$_});
 	} sort keys %c;
