@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2020 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -35,14 +35,14 @@ use NeedRestart::Utils;
 
 my $LOGPREF = '[Python]';
 
-needrestart_interp_register(__PACKAGE__);
+needrestart_interp_register(__PACKAGE__, "python");
 
 sub isa {
     my $self = shift;
     my $pid = shift;
     my $bin = shift;
 
-    return 1 if($bin =~ m@/usr/(local/)?bin/python@);
+    return 1 if($bin =~ m@^/usr/(local/)?bin/python([23][.\d]*)?$@);
 
     return 0;
 }
@@ -198,14 +198,14 @@ sub files {
     elsif(exists($ENV{PYTHONPATH})) {
 	delete($ENV{PYTHONPATH});
     }
-    
+
     # get include path
     my ($pyread, $pywrite) = nr_fork_pipe2($self->{debug}, $ptable->{exec}, '-');
     print $pywrite "import sys\nprint(sys.path)\n";
     close($pywrite);
     my ($path) = <$pyread>;
     close($pyread);
-    
+
     # look for module source files
     my @path;
     if(defined($path)) {
@@ -217,7 +217,7 @@ sub files {
     else {
 	print STDERR "$LOGPREF #$pid: failed to retrieve include path\n" if($self->{debug});
     }
-    
+
     my %files;
     _scan($self->{debug}, $pid, $src, \%files, \@path);
 
